netapp_ontap.models.lun_space API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.lun_space`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class LunSpaceSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the LunSpace object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `efficiency_ratio: float GET`

    The storage efficiency ratio of the LUN without snapshots. (Logical Used / Used) This property is not available on the LUN object in the REST API and is not reported for GET requests. See the containing volume object for this information. Available for GET.

    Example: 2.5

  `guarantee: LunSpaceGuarantee GET POST PATCH`

    Properties that request and report the space guarantee for the LUN.

  `physical_used: Size GET`

    The number of bytes consumed on the disk by the LUN, excluding snapshots. This property is not available on the LUN object in the REST API and is not reported for GET requests. See the containing volume object for this information. Available for GET.

    Example: 1073741824

  `physical_used_by_snapshots: Size GET`

    The number of bytes consumed on the disk by the LUN's snapshots. This property has been replaced by `space.snapshot.used`. This property is not available on the LUN object in the REST API and is not reported for GET requests. See the containing volume object for this information. Available for GET.

    Example: 1073741824

  `scsi_thin_provisioning_support_enabled: bool GET POST PATCH`

    To leverage the benefits of SCSI thin provisioning, it must be supported by your host. SCSI thin provisioning uses the Logical Block Provisioning feature as defined in the SCSI SBC-3 standard. Only hosts that support this standard can use SCSI thin provisioning in ONTAP.
    When you disable SCSI thin provisioning support in ONTAP, you turn off the following SCSI thin provisioning features: - Unmapping and reporting space usage for space reclamation - Reporting resource exhaustion errors

    The value of this property is not propagated to the destination when a LUN is cloned as a new LUN or copied; it is reset to false. The value of this property is maintained from the destination LUN when a LUN is overwritten as a clone.
    Valid in POST and PATCH. This property cannot be set. All LUNs are provisioned with SCSI thin provisioning enabled.

  `size: Size GET POST PATCH`

    The total provisioned size of the LUN. The LUN size can be increased but not decreased using the REST interface.
    The maximum and minimum sizes listed here are the absolute maximum and absolute minimum sizes, in bytes. The actual minimum and maximum sizes vary depending on the ONTAP version, ONTAP platform and the available space in the containing volume and aggregate.
    For more information, see Size properties in the docs section of the ONTAP REST API documentation.

    Example: 1073741824

  `snapshot: VdiskSpaceSnapshot GET POST PATCH`

    The snapshot field of the lun_space.

  `used: Size GET`

    The amount of space consumed by the main data stream of the LUN.
    This value is the total space consumed in the volume by the LUN, including filesystem overhead, but excluding prefix and suffix streams. Due to internal filesystem overhead and the many ways SAN filesystems and applications utilize blocks within a LUN, this value does not necessarily reflect actual consumption/availability from the perspective of the filesystem or application. Without specific knowledge of how the LUN blocks are utilized outside of ONTAP, this property should not be used as an indicator for an out-of-space condition.
    For more information, see Size properties in the docs section of the ONTAP REST API documentation.